import pandas
import matplotlib.pyplot as plt
from matplotlib import ticker
from matplotlib import rcParams

rcParams['font.family'] = 'sans-serif'
rcParams['font.sans-serif'] = ['Hiragino Maru Gothic Pro', 'Yu Gothic']

pandas.set_option('display.unicode.east_asian_width', True)

df = pandas.read_csv('c6_c02.csv', encoding='shift-jis')
df2 = df.loc[:, ['西暦（年）', '年齢5歳階級', '人口（総数）']]
df3 = df2.loc[df2['年齢5歳階級'] != '総数']

rank = df3['年齢5歳階級'].replace('[〜|歳以上].*', '', regex=True)
rank.name = 'rank'
rank = pandas.to_numeric(rank, errors='coerce')
df4 = pandas.concat([df3, rank], axis=1)

df5 = df4.pivot_table(index='西暦（年）', columns='rank', values='人口（総数）')

ax = df5.plot(kind='area', figsize=(9, 6))
ax.yaxis.set_major_formatter(ticker.StrMethodFormatter('{x:,.0f}'))
ax.legend(loc='upper left', bbox_to_anchor=(0.99, 1.0))
plt.show()
